from setuptools import setup
setup(
    name="validate_adhar",
    version="1.0.1",
    description='This Package is a Function to validate Adhaar Car and name',
    author='Oswald Fernandes',
    author_email='oswfernand@yahoo.com',
    packages=['validate_adhar']
)


def validate_adhar_details(adhar_number,adhar_name):
    if len(adhar_number)!= 12:
        print('Invalid Adhar Number, Pleas re-enter: ')
        return False
    if len(adhar_name)<3:
        print('Invalid Adhar Name, Please re-enter:')
        return False
    return True
